============
Introduction
============

| This is **Python Object Getter**, a *Python Package* desinged to ...

| Goal of this project is to ..
| Additionally, ...

| This documentation aims to help people understand what are the package's features and to demonstrate
| how to leverage them for their use cases.
| It also presents the overall package design.
